@@ -1,20 +1,22 @@
 package Reddit::Client::Comment;
 
+use strict;
+use warnings;
 use Carp;
 
 require Reddit::Client::VotableThing;
 
 use base   qw/Reddit::Client::VotableThing/;
 use fields qw/link_flair_text media url link_flair_css_class num_reports created_utc
-			  banned_by subreddit title author_flair_text is_self author media_embed
-			  permalink author_flair_css_class selftext domain num_comments clicked
-			  saved thumbnail subreddit_id approved_by selftext_html created hidden
-			  over_18 parent_id replies link_id body body_html/;
+              banned_by subreddit title author_flair_text is_self author media_embed
+              permalink author_flair_css_class selftext domain num_comments clicked
+              saved thumbnail subreddit_id approved_by selftext_html created hidden
+              over_18 parent_id replies link_id body body_html/;
 
 sub set_replies {
     my ($self, $value) = @_;
     if (ref $value && exists $value->{data}{children}) {
-	    $self->{replies} = [ map { Reddit::Client::Comment->new($self->{_session}, $_->{data}) } @{$value->{data}{children}} ];
+        $self->{replies} = [ map { Reddit::Client::Comment->new($self->{session}, $_->{data}) } @{$value->{data}{children}} ];
     } else {
         $self->{replies} = [];
     }
@@ -74,6 +76,10 @@ Jeff Ober L<mailto:jeffober@gmail.com>
 
 =head1 LICENSE
 
-BSD license
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
 
 =cut
